@@ -1,9 +1,11 @@
 package Org::To::HTML;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2018-05-05'; # DATE
+our $VERSION = '0.230'; # VERSION
 
-use 5.010;
+use 5.010001;
+use strict;
+use warnings;
 use Log::ger;
 
 use vars qw($VERSION);
@@ -138,29 +140,29 @@ sub export_document {
 
     my $html = [];
     unless ($self->naked) {
-        push @$html, "<HTML>\n";
+        push @$html, "<html>\n";
         push @$html, (
             "<!-- Generated by ".__PACKAGE__,
             " version ".($VERSION // "?"),
             " on ".scalar(localtime)." -->\n\n");
 
-        push @$html, "<HEAD>\n";
-        push @$html, "<TITLE>",
-            ($self->html_title // "(no title)"), "</TITLE>\n";
+        push @$html, "<head>\n";
+        push @$html, "<title>",
+            ($self->html_title // "(no title)"), "</title>\n";
         if ($self->css_url) {
             push @$html, (
-                "<LINK REL=\"stylesheet\" TYPE=\"text/css\" HREF=\"",
+                "<link rel=\"stylesheet\" type=\"text/css\" href=\"",
                 $self->css_url, "\" />\n"
             );
         }
-        push @$html, "</HEAD>\n\n";
+        push @$html, "</head>\n\n";
 
-        push @$html, "<BODY>\n";
+        push @$html, "<body>\n";
     }
     push @$html, $self->export_elements(@{$doc->children});
     unless ($self->naked) {
-        push @$html, "</BODY>\n\n";
-        push @$html, "</HTML>\n";
+        push @$html, "</body>\n\n";
+        push @$html, "</html>\n";
     }
 
     join "", @$html;
@@ -178,18 +180,18 @@ sub export_block {
     my ($self, $elem) = @_;
     # currently all assumed to be <PRE>
     join "", (
-        "<PRE CLASS=\"block block_", lc($elem->name), "\">",
+        "<pre class=\"block block_", lc($elem->name), "\">",
         encode_entities($elem->raw_content),
-        "</PRE>\n\n"
+        "</pre>\n\n"
     );
 }
 
 sub export_fixed_width_section {
     my ($self, $elem) = @_;
     join "", (
-        "<PRE CLASS=\"fixed_width_section\">",
+        "<pre class=\"fixed_width_section\">",
         encode_entities($elem->text),
-        "</PRE>\n"
+        "</pre>\n"
     );
 }
 
@@ -220,9 +222,9 @@ sub export_headline {
     my @children = $self->_included_children($elem);
 
     join "", (
-        "<H" , $elem->level, ">",
+        "<h" , $elem->level, ">",
         $self->export_elements($elem->title),
-        "</H", $elem->level, ">\n\n",
+        "</h", $elem->level, ">\n\n",
         $self->export_elements(@children)
     );
 }
@@ -231,9 +233,9 @@ sub export_list {
     my ($self, $elem) = @_;
     my $tag;
     my $type = $elem->type;
-    if    ($type eq 'D') { $tag = 'DL' }
-    elsif ($type eq 'O') { $tag = 'OL' }
-    elsif ($type eq 'U') { $tag = 'UL' }
+    if    ($type eq 'D') { $tag = 'dl' }
+    elsif ($type eq 'O') { $tag = 'ol' }
+    elsif ($type eq 'U') { $tag = 'ul' }
     join "", (
         "<$tag>\n",
         $self->export_elements(@{$elem->children // []}),
@@ -246,27 +248,27 @@ sub export_list_item {
 
     my $html = [];
     if ($elem->desc_term) {
-        push @$html, "<DT>";
+        push @$html, "<dt>";
     } else {
-        push @$html, "<LI>";
+        push @$html, "<li>";
     }
 
     if ($elem->check_state) {
-        push @$html, "<STRONG>[", $elem->check_state, "]</STRONG>";
+        push @$html, "<strong>[", $elem->check_state, "]</strong>";
     }
 
     if ($elem->desc_term) {
         push @$html, $self->export_elements($elem->desc_term);
-        push @$html, "</DT>";
-        push @$html, "<DD>";
+        push @$html, "</dt>";
+        push @$html, "<dd>";
     }
 
     push @$html, $self->export_elements(@{$elem->children}) if $elem->children;
 
     if ($elem->desc_term) {
-        push @$html, "</DD>\n";
+        push @$html, "</dd>\n";
     } else {
-        push @$html, "</LI>\n";
+        push @$html, "</li>\n";
     }
 
     join "", @$html;
@@ -287,18 +289,18 @@ sub export_setting {
 sub export_table {
     my ($self, $elem) = @_;
     join "", (
-        "<TABLE BORDER>\n",
+        "<table border>\n",
         $self->export_elements(@{$elem->children // []}),
-        "</TABLE>\n\n"
+        "</table>\n\n"
     );
 }
 
 sub export_table_row {
     my ($self, $elem) = @_;
     join "", (
-        "<TR>",
+        "<tr>",
         $self->export_elements(@{$elem->children // []}),
-        "</TR>\n"
+        "</tr>\n"
     );
 }
 
@@ -306,9 +308,9 @@ sub export_table_cell {
     my ($self, $elem) = @_;
 
     join "", (
-        "<TD>",
+        "<td>",
             $self->export_elements(@{$elem->children // []}),
-        "</TD>"
+        "</td>"
     );
 }
 
@@ -328,7 +330,7 @@ sub export_target {
     my ($self, $elem) = @_;
     # target
     join "", (
-        "<A NAME=\"", __escape_target($elem->target), "\">"
+        "<a name=\"", __escape_target($elem->target), "\">"
     );
 }
 
@@ -337,12 +339,12 @@ sub export_text {
 
     my $style = $elem->style;
     my $tag;
-    if    ($style eq 'B') { $tag = 'B' }
-    elsif ($style eq 'I') { $tag = 'I' }
-    elsif ($style eq 'U') { $tag = 'U' }
-    elsif ($style eq 'S') { $tag = 'STRIKE' }
-    elsif ($style eq 'C') { $tag = 'CODE' }
-    elsif ($style eq 'V') { $tag = 'TT' }
+    if    ($style eq 'B') { $tag = 'b' }
+    elsif ($style eq 'I') { $tag = 'i' }
+    elsif ($style eq 'U') { $tag = 'u' }
+    elsif ($style eq 'S') { $tag = 'strike' }
+    elsif ($style eq 'C') { $tag = 'code' }
+    elsif ($style eq 'V') { $tag = 'tt' }
 
     my $html = [];
 
@@ -376,7 +378,7 @@ sub export_link {
     my ($self, $elem) = @_;
 
     my $html = [];
-    push @$html, "<A HREF=\"";
+    push @$html, "<a href=\"";
     if ($elem->link =~ m!^\w+:!) {
         # looks like a url
         push @$html, $elem->link;
@@ -390,7 +392,7 @@ sub export_link {
     } else {
         push @$html, $elem->link;
     }
-    push @$html, "</A>";
+    push @$html, "</a>";
 
     join "", @$html;
 }
@@ -410,7 +412,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.22 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2017-07-10.
+This document describes version 0.230 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2018-05-05.
 
 =head1 SYNOPSIS
 
@@ -579,7 +581,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
